@@ -4,9 +4,10 @@
 .onLoad <- function(libname, pkgname) {
   ## set options using the approach used by devtools
   opts <- options()
+  reproCachePath <- getOption("reproducible.cachePath")
   opts.spades <- list( # nolint
     spades.browserOnError = FALSE,
-    spades.cachePath = file.path(.spadesTempDir, "cache"),
+    #spades.cachePath = reproCachePath,
     spades.debug = TRUE, # TODO: is this the best default? see discussion in #5
     spades.inputPath = file.path(.spadesTempDir, "inputs"),
     spades.lowMemory = FALSE,
@@ -21,6 +22,7 @@
     spades.moduleRepo = "PredictiveEcology/SpaDES-modules",
     spades.nCompleted = 10000L,
     spades.outputPath = file.path(.spadesTempDir, "outputs"),
+    spades.saveSimOnExit = TRUE,
     spades.switchPkgNamespaces = FALSE,
     spades.tolerance = .Machine$double.eps ^ 0.5,
     spades.useragent = "http://github.com/PredictiveEcology/SpaDES",
@@ -42,6 +44,14 @@
   }
   .pkgEnv[["unitConversions"]] <- as.matrix(as.data.frame(bbs))
 
+  # Create active binding for "Paths"
+  pkgEnv <- parent.env(environment())
+  rm("Paths", envir = pkgEnv)
+  makeActiveBinding(sym = "Paths",
+                    fun = function() .paths(),
+                    env = pkgEnv
+  )
+
   invisible()
 }
 
@@ -50,33 +60,44 @@
 .onAttach <- function(libname, pkgname) {
   if (interactive()) {
     packageStartupMessage("Using SpaDES.core version ", utils::packageVersion("SpaDES.core"), ".")
+    a <- capture.output(setPaths(), type = "message")
+    a <- paste(a, collapse = "\n")
+    packageStartupMessage(a)
     packageStartupMessage(
-      "Default paths for SpaDES directories set to:\n",
-      "  cachePath:  ", reproducible::normPath(.getOption("spades.cachePath")), "\n",
-      "  inputPath:  ", reproducible::normPath(getOption("spades.inputPath")), "\n",
-      "  modulePath: ", reproducible::normPath(getOption("spades.modulePath")), "\n",
-      "  outputPath: ", reproducible::normPath(getOption("spades.outputPath")), "\n",
-      "These can be changed using 'setPaths()'. See '?setPaths'."
+      "To change these, use setPaths(...); see ?setPaths"
     )
   }
+  #unlockBinding("Paths", as.environment("package:SpaDES.core"))
+  # rm("Paths", envir = as.environment("package:SpaDES.core"))
+  # makeActiveBinding(sym = "Paths",
+  #                   fun = function() {
+  #                     SpaDES.core:::.paths()
+  #                   },
+  #                   env = as.environment("package:SpaDES.core")
+  #                   #env = environment()#"package:SpaDES.core")
+  # )
+  # #lockBinding("Paths", as.environment("package:SpaDES.core"))
+
+  # rm("Paths", envir = as.environment("package:SpaDES.core"))
+  # makeActiveBinding(sym = "Paths",
+  #                   fun = function() {
+  #                     .paths()
+  #                   },
+  #                   env = as.environment("package:SpaDES.core")
+  # )
+  # lockBinding("Paths", as.environment("package:SpaDES.core"))
 
-  rm("Paths", envir = as.environment("package:SpaDES.core"))
-  makeActiveBinding(sym = "Paths",
-                    fun = .paths,
-                    env = as.environment("package:SpaDES.core")
-  )
-  lockBinding("Paths", as.environment("package:SpaDES.core"))
 }
 
 .onUnload <- function(libpath) {
   ## if temp session dir is being used, ensure it gets reset each session
-  if (.getOption("spades.cachePath") == file.path(.spadesTempDir, "cache")) {
-    options(spades.cachePath = NULL)
-  }
+  #if (.getOption("spades.cachePath") == file.path(.spadesTempDir, "cache")) {
+  #  options(spades.cachePath = NULL)
+  #}
   if (getOption("spades.inputPath") == file.path(.spadesTempDir, "inputs")) {
     options(spades.inputPath = NULL)
   }
-  if (getOption("spades.modulePath") == file.path(.spadesTempDir, "modules")) {
+  if (all(getOption("spades.modulePath") %in% file.path(.spadesTempDir, "modules"))) {
     options(spades.modulePath = NULL)
   }
   if (getOption("spades.outputPath") == file.path(.spadesTempDir, "outputs")) {
