@@ -42,15 +42,15 @@ defineModule(sim, list(
     defineParameter(".saveInterval", "numeric", NA_real_, NA, NA, "time interval between save events")
   ),
   inputObjects = bind_rows(
-    expectsInput(objectName = P(sim, "fireSpread")$stackName, objectClass = "RasterStack",
+    expectsInput(objectName = SpaDES.core::P(sim, "fireSpread")$stackName, objectClass = "RasterStack",
                  desc = NA_character_, sourceURL = NA_character_),
-    expectsInput(objectName = globals(sim)$burnStats, objectClass = "numeric",
+    expectsInput(objectName = SpaDES.core::globals(sim)$burnStats, objectClass = "numeric",
                  desc = NA_character_, sourceURL = NA_character_)
   ),
   outputObjects = bind_rows(
-    createsOutput(objectName = P(sim, "fireSpread")$stackName, objectClass = "RasterStack",
+    createsOutput(objectName = SpaDES.core::P(sim, "fireSpread")$stackName, objectClass = "RasterStack",
                   desc = NA_character_, other = NA_character_),
-    createsOutput(objectName = globals(sim)$burnStats, objectClass = "numeric",
+    createsOutput(objectName = SpaDES.core::globals(sim)$burnStats, objectClass = "numeric",
                   desc = NA_character_, other = NA_character_)
   )
 ))
@@ -62,12 +62,12 @@ doEvent.fireSpread <- function(sim, eventTime, eventType, debug = FALSE) {
     init = {
       ### check for more object dependencies:
       ### (use `checkObject` or similar)
-      checkObject(sim, P(sim)$stackName, layer = "habitatQuality")
+      SpaDES.core::checkObject(sim, SpaDES.core::P(sim)$stackName, layer = "habitatQuality")
 
-      if (is.null(sim[[globals(sim)$burnStats]])) {
-        sim[[globals(sim)$burnStats]] <- numeric()
+      if (is.null(sim[[SpaDES.core::globals(sim)$burnStats]])) {
+        sim[[SpaDES.core::globals(sim)$burnStats]] <- numeric()
       } else {
-        npix <- sim[[(globals(sim)$burnStats)]]
+        npix <- sim[[(SpaDES.core::globals(sim)$burnStats)]]
         stopifnot("numeric" %in% is(npix), "vector" %in% is(npix))
       }
 
@@ -75,9 +75,9 @@ doEvent.fireSpread <- function(sim, eventTime, eventType, debug = FALSE) {
       sim <- Init(sim)
 
       # schedule the next events
-      sim <- scheduleEvent(sim, P(sim)$startTime, "fireSpread", "burn")
-      sim <- scheduleEvent(sim, P(sim)$.saveInterval, "fireSpread", "save", .last())
-      sim <- scheduleEvent(sim, P(sim)$.plotInitialTime, "fireSpread", "plot.init", .last())
+      sim <- scheduleEvent(sim, SpaDES.core::P(sim)$startTime, "fireSpread", "burn")
+      sim <- scheduleEvent(sim, SpaDES.core::P(sim)$.saveInterval, "fireSpread", "save", .last())
+      sim <- scheduleEvent(sim, SpaDES.core::P(sim)$.plotInitialTime, "fireSpread", "plot.init", .last())
     },
     burn = {
       # do stuff for this event
@@ -85,7 +85,7 @@ doEvent.fireSpread <- function(sim, eventTime, eventType, debug = FALSE) {
 
       # schedule the next events
       sim <- scheduleEvent(sim, time(sim), "fireSpread", "stats") # do stats immediately following burn
-      sim <- scheduleEvent(sim, time(sim) + P(sim)$returnInterval, "fireSpread", "burn")
+      sim <- scheduleEvent(sim, time(sim) + SpaDES.core::P(sim)$returnInterval, "fireSpread", "burn")
     },
     stats = {
       # do stuff for this event
@@ -96,7 +96,7 @@ doEvent.fireSpread <- function(sim, eventTime, eventType, debug = FALSE) {
     },
     plot.init = {
       # do stuff for this event
-      setColors(sim[[P(sim)$stackName]], n = c(Fires = 10)) <- list(
+      setColors(sim[[SpaDES.core::P(sim)$stackName]], n = c(Fires = 10)) <- list(
         DEM = brewer.pal(9, "YlOrBr"),
         forestAge = brewer.pal(9, "BuGn"),
         habitatQuality = brewer.pal(8, "Spectral"),
@@ -105,20 +105,21 @@ doEvent.fireSpread <- function(sim, eventTime, eventType, debug = FALSE) {
       )
 
       clearPlot()
-      Plot(sim[[P(sim)$stackName]],
-           legendRange = list(0:maxValue(sim[[P(sim)$stackName]]$DEM), 0:100,
+      stackName <- SpaDES.core::P(sim)$stackName # Plot doesn't like long names -- create local variable
+      Plot(sim[[stackName]],
+           legendRange = list(0:maxValue(sim[[SpaDES.core::P(sim)$stackName]]$DEM), 0:100,
                               c(0, 1), 0:100, 0:10))
 
       # schedule the next event
-      sim <- scheduleEvent(sim, time(sim) + P(sim)$.plotInterval,
+      sim <- scheduleEvent(sim, time(sim) + SpaDES.core::P(sim)$.plotInterval,
                            "fireSpread", "plot", .last())
     },
     plot = {
       # do stuff for this event
-      Plot(sim[[P(sim)$stackName]]$Fires, new = FALSE)
+      Plot(sim[[SpaDES.core::P(sim)$stackName]]$Fires, new = FALSE)
 
       # schedule the next event
-      sim <- scheduleEvent(sim, time(sim) + P(sim)$.plotInterval,
+      sim <- scheduleEvent(sim, time(sim) + SpaDES.core::P(sim)$.plotInterval,
                            "fireSpread", "plot", .last())
     },
     save = {
@@ -126,7 +127,7 @@ doEvent.fireSpread <- function(sim, eventTime, eventType, debug = FALSE) {
       sim <- saveFiles(sim)
 
       # schedule the next event
-      sim <- scheduleEvent(sim, time(sim) + P(sim)$.saveInterval,
+      sim <- scheduleEvent(sim, time(sim) + SpaDES.core::P(sim)$.saveInterval,
                            "fireSpread", "save", .last() + 1)
     },
     warning(paste(
@@ -140,7 +141,7 @@ doEvent.fireSpread <- function(sim, eventTime, eventType, debug = FALSE) {
 
 ## event functions
 Init <- function(sim) {
-  landscapes <- sim[[P(sim)$stackName]]
+  landscapes <- sim[[SpaDES.core::P(sim)$stackName]]
 
   ### create burn map that tracks fire locations over time
   Fires <- raster(extent(landscapes), ncol = ncol(landscapes),
@@ -151,39 +152,39 @@ Init <- function(sim) {
 
   # add Fires map to global$stackName stack
   landscapes$Fires <- Fires
-  sim[[P(sim)$stackName]] <- landscapes
+  sim[[SpaDES.core::P(sim)$stackName]] <- landscapes
 
   return(invisible(sim))
 }
 
 Burn <- function(sim) {
-  landscapes <- sim[[P(sim)$stackName]]
+  landscapes <- sim[[SpaDES.core::P(sim)$stackName]]
 
   Fires <- spread(landscapes[[1]],
-                  loci = as.integer(sample(1:ncell(landscapes), P(sim)$nFires)),
-                  spreadProb = P(sim)$spreadprob,
-                  persistance = P(sim)$persistprob,
+                  loci = as.integer(sample(1:ncell(landscapes), SpaDES.core::P(sim)$nFires)),
+                  spreadProb = SpaDES.core::P(sim)$spreadprob,
+                  persistance = SpaDES.core::P(sim)$persistprob,
                   mask = NULL,
                   maxSize = 1e8,
                   directions = 8,
-                  iterations = P(sim)$its,
+                  iterations = SpaDES.core::P(sim)$its,
                   plot.it = FALSE,
                   id = TRUE)
   names(Fires) <- "Fires"
   setColors(Fires) <- c("white", rev(heat.colors(9)))
   landscapes$Fires <- Fires
 
-  sim[[P(sim)$stackName]] <- landscapes
+  sim[[SpaDES.core::P(sim)$stackName]] <- landscapes
 
   return(invisible(sim))
 }
 
 Stats <- function(sim) {
-  npix <- sim[[globals(sim)$burnStats]]
+  npix <- sim[[SpaDES.core::globals(sim)$burnStats]]
 
-  landscapes <- sim[[P(sim)$stackName]]
+  landscapes <- sim[[SpaDES.core::P(sim)$stackName]]
 
-  sim[[globals(sim)$burnStats]] <- c(npix, length(which(values(landscapes$Fires) > 0)))
+  sim[[SpaDES.core::globals(sim)$burnStats]] <- c(npix, length(which(values(landscapes$Fires) > 0)))
 
   return(invisible(sim))
 }
