@@ -19,68 +19,125 @@ test_that("simulation runs with simInit and spades", {
   mySim <- simInit(times, params, modules, objects = list(), paths) %>%
     spades(debug = FALSE)
 
-  # simtime
+  ## simtime
   expect_equivalent(time(mySim), 10.0)
   expect_equivalent(start(mySim), 0.0)
   expect_equivalent(end(mySim), 10.0)
 
-  # sim results ## NOTE upcoming version of RandomFields completely changes the values!!!
-  #if (utils::packageVersion("RandomFields") >= "3.1.20") {
-  burnedLast <- c(1725, 126, 816, 2136, 1836, 825, 1381, 1507, 1509, 1624)
+  ## sim results
+  ## NOTE: version 3.3.4 of RandomFields completely changed the values!!!
+  ## TODO: figure out why R-devel is completely different
 
-  pos_x <- c(1.05944046146596, 44.4530163547364, 45.8793618542196,
-             -1.31587161139159, 17.8640418602947, 48.4840937544703, 10.7535089382283,
-             -24.6253107925863, -48.5108426726095, -7.76764412474417, 34.7851382149642,
-             9.83572522829692, 41.9505922251921, -9.07555369460079, -39.676662136738,
-             21.6185984474158, 46.4701522375152, -0.883315154385187, 28.0911201823354,
-             -13.847369533562, -49.7727146829549, -16.2936810258016, -33.9335427084662,
-             -8.47926857699624, -17.5993028014645, -33.0461085829127, 24.8750808532409,
-             -43.5077879392023, -16.9752324398488, 16.7694485345211, -8.91563038316473,
-             -48.3650161814635, 27.0749755681643, 34.0994637648402, -49.1648592745971,
-             -29.9712621173336, 49.5667313041262, 21.3612681252904, -21.3445953954488,
-             24.8211683871312, 23.4173005016891, -29.9699855919438, -49.958594066106,
-             -17.825402853539, 30.0307948992073, 29.6380142083718, 49.6506417101735,
-             -44.1750870723644, -32.8472885698896, 12.7607439556149, -15.7741569225653,
-             -41.5405111886502, -34.8179542704289, -38.3885023832212, 4.60137973293355,
-             -22.6440580206797, -0.213427106250919, -2.29987838737896, -21.081170253662,
-             38.454598692853, 15.1416694346051, -43.728082307768, -13.0723350036922,
-             28.0846481560228, -27.3096141757915, 45.7054711281168, 9.16013996497286,
-             9.62565605939507, -16.0461041502597, -35.5546251289444, -24.9716699563686,
-             49.8465322556856, 10.8257847829093, -34.2753709391232, -10.4856247161767,
-             48.8397137324941, 16.7101178052949, -35.4992391966538, -49.0238384344422,
-             47.597755712123, -20.1128595601079, 44.2571096499243, -34.507735468028,
-             35.4557823272802, 49.5489237085567, 31.1401253978472, 25.3007340967458,
-             6.45953149953921, -46.7962501020211, 1.03386467153074, -24.1707710493782,
-             35.2616940703965, -1.12871674368546, 46.1499998989781, 30.4491021819093,
-             -26.5440703974598, -39.6645892713107, -28.1460804729089, -41.6606455063026,
-             -7.39377404125834)
+  if (as.numeric_version(paste0(R.version$major, ".", R.version$minor)) < "3.6.0") {
+    burnedLast <- c(1725, 126, 816, 2136, 1836, 825, 1381, 1507, 1509, 1624)
 
-  pos_y <- c(-15.8993972461616, -8.96685346602316, 25.2653183350009,
-             -39.0714808439679, -32.9641113081288, 19.5922174069934, 14.8674025804159,
-             38.2616003081126, -8.16583605869974, 17.8252525894824, 8.21593603120944,
-             -36.3379915713033, 29.7329787318616, 42.0827238488804, -20.2386772454794,
-             35.7556518838588, 5.55152952583172, 27.7482179433487, 37.4124616940735,
-             -42.4068608457502, -22.1109081515469, 10.2089709119964, -3.45245440515526,
-             -12.0062733527654, 5.19230996990487, -27.1646572653389, -26.8632992341179,
-             12.4455696770408, 39.5029725546056, -40.8904798063864, 13.4903138848752,
-             -9.33150580154056, 12.266246498016, 27.8095419155339, 8.94181503604101,
-             24.4028888129788, -44.3392208269988, 36.7910379389471, -45.1228359607758,
-             -35.9317653139032, 6.31296435991845, 20.9073748145245, -16.3575394819696,
-             22.4740052505691, 36.7314942719821, -3.77070330422793, -30.2931909279016,
-             16.583785813993, 38.7946206773652, -12.6087368305901, -3.99514927265182,
-             15.0189478879167, 27.1011443151554, -19.4368853267691, -6.71379469116036,
-             18.2862630593746, -40.2802146105095, -15.6248800198687, 32.2775346771305,
-             31.4803155819967, 45.0553762113152, 25.7675846881672, -49.8075671509248,
-             -6.86962262435439, 14.4530466734969, -5.96936453527461, 3.86969432620594,
-             -35.3152672431326, -15.5041801097397, -36.2079856152726, -10.8110700378683,
-             -48.6952585997799, -30.7297095345783, -42.2974065446223, 7.53790808198442,
-             -9.89011549737592, 30.0073720455366, 48.1503933132591, -32.8646234493861,
-             -46.9746807507946, -21.8590265307828, -2.9748266389963, 2.86405420190562,
-             -43.7889401248308, 10.0365696344108, 44.4795579080847, -48.3616605982961,
-             1.2228017579147, 4.04249242242624, 33.1075803768298, 4.64441718295845,
-             -47.8216259071557, 33.265393363792, 40.0764181461184, 42.4561064648432,
-             20.6604237095649, -41.4412266891093, 9.96154914243285, 33.2776014337331,
-             12.9988550096717)
+    pos_x <- c(3.67198762961861, 43.5696708785149, 47.2305734618245, 3.60246886799683,
+               20.2341208513449, -47.8103385360554, 16.549667617437, -21.4073219999126,
+               -47.2769911726926, -6.90873327788373, 36.835560427439, 12.9374835943128,
+               40.5674117042784, -11.7361472823519, -41.5713366897425, 34.5473813500302,
+               48.7716328246997, 1.17105329929266, 35.5846164245956, -7.86561428907069,
+               -46.3823959510007, -15.5702817526754, -30.8126668166424, -10.8010597558361,
+               -21.621652166683, -34.9716907591623, 25.5631391945506, -39.4952612681468,
+               -25.1246681360093, 21.622935348448, -14.4866699835992, -49.0314824104314,
+               29.5110481868387, 29.2980035604069, -43.4047992834982, -29.9034739927016,
+               -47.4019699552285, 16.4433227782692, -14.9724014492504, 29.3395340026156,
+               13.6774863068155, -34.9815939568256, -49.2326424452628, -24.63099179726,
+               29.5125886276067, 23.458819195019, -49.267195519905, -38.9791254541313,
+               -28.2266566260833, 13.5885336184307, -20.6503350281957, -33.8303967733853,
+               -24.1745353595507, -31.3420623391095, 6.61947623399171, -21.1950814939711,
+               -1.33380687943018, -3.75424367990195, -14.1989815964155, 39.9509364652245,
+               11.3294250869671, -45.6319461016064, -20.4925846467192, 33.5846108424744,
+               -27.8641689486461, 49.2799565507116, 10.6300284406548, 9.82084260223184,
+               -14.0267505658531, -38.7461668664082, -17.4223198195779, -42.0410983042247,
+               13.116781230502, -30.2946890723426, -7.24177892193424, -48.5130451079312,
+               17.1057771797333, -34.2704160400112, 45.5029029338103, -45.8001752305177,
+               -17.2400741380727, 44.8468809094991, -30.2109608623335, 36.1406259127961,
+               49.5797105154377, 37.9715152273499, 28.9228258650546, 0.0171507589597368,
+               -49.8120291449472, -0.98955203861027, -23.0873331875497, 37.1384151375969,
+               -5.71780586016212, 43.5434737540987, 30.4242728959723, -26.1180246775251,
+               -41.1416482549562, -27.6357211052713, -44.4316026481829, -5.95912959330009)
+
+    pos_y <- c(-15.001761220824, -5.35080605403711, 19.5077777843759, -36.397145230444,
+               -33.6423155958808, 15.5654887730343, 15.1161302639245, 39.6292863891733,
+               -6.33467507909924, 18.7170224485725, 9.9439345128018, -35.6163117424963,
+               30.3189149133229, 36.3302747888531, -20.5841744054804, 35.0724288881633,
+               6.89301514649688, 26.6513337958583, 40.7971294972673, -42.5921974005888,
+               -25.1956144258027, 8.07885129937992, -4.96023665998145, -17.0580144244664,
+               6.70757582479894, -30.0547962733918, -26.9514004855529, 9.51961127097033,
+               45.8924961557304, -35.064160676, 15.9600129744977, -11.0340528019363,
+               15.0513989967463, 28.2511337198897, 12.6024406421523, 29.6186430588117,
+               -39.7428219762265, 35.4932893119247, -43.7241362328051, -37.9005457120927,
+               12.0957051751919, 23.8288477776908, -19.2354379455293, 23.8879129871873,
+               33.7143251941822, -3.12072701146833, -31.6235585354086, 16.7528980653008,
+               36.7097153167129, -11.7295242023283, -6.94989772244249, 13.9367056129548,
+               28.4679184711446, -15.8080671318301, -3.55494838851763, 14.9708684826552,
+               -38.8792113697679, -15.9961364230978, 37.0641490103275, 37.8956868303261,
+               47.326711092004, 26.553518278515, -49.1534947969543, -10.7774399881724,
+               15.8927912475565, -6.9736291044513, 3.01107884790719, -33.4855281463676,
+               -11.9831588943045, -38.8181249029193, -6.62110647477371, 45.9736674749952,
+               -34.1942437078733, -40.9635623302871, 5.17629246277392, -6.68267453641167,
+               29.1209898564489, 45.3398473666519, -30.5369457698111, -42.9088551558613,
+               -19.1027196578503, -4.02030489693142, 2.12143116091905, -44.4144553066295,
+               10.7604128113847, -49.9396648839783, 45.0920147869853, -0.0581486970932161,
+               9.09784601154538, 35.1429818255256, 1.65204980292364, -46.334526877774,
+               32.4348917623925, 38.1377734360978, 44.4057542471017, 19.6370212341059,
+               -47.8588704211158, 12.5778638346433, 27.527048666893, 7.68312730236396)
+  } else {
+    ## development version produces different results
+    burnedLast <- c(1623, 201, 723, 2036, 1561, 739, 1836, 2024, 1798, 1339)
+
+    pos_x <- c(13.0532707978136, -32.8923908957165, 27.3969797389589, 38.9968311591861,
+               -29.7376281316361, 17.6101067673529, -18.0977082950375, 24.5274747285482,
+               -31.7189715804585, 7.381959991136, -43.9760214431076, -21.6972114900354,
+               -49.5278149392391, 2.43127242195319, 16.0134685436804, -10.8459282001756,
+               25.2180607454783, -1.7723351523618, -18.250212230032, -7.71846859821378,
+               13.3820348997256, -4.38164903104301, -20.9431540816844, -36.998943651721,
+               -17.8923147847315, -28.1370858241664, 5.61463577954896, -10.8043913485292,
+               31.8712545591271, 5.64559917365374, -27.3013571395529, 5.65249374187498,
+               -10.8303539587148, 13.4035832312236, -16.000923747874, -19.7411280170716,
+               -49.9816367287749, -37.6135951927579, 2.66195570061529, 39.0068015622127,
+               -37.8160698182155, 31.4230204779793, -17.2974671375295, -41.3562749525678,
+               -38.9645106419225, 2.96198358254623, -40.7250620074311, 27.9062680492077,
+               10.8307589967548, -21.8711284922136, -16.6113099460494, -13.4123971497708,
+               -23.7813281135169, 5.59680019423666, -22.8738222538764, -4.61301507814081,
+               -0.544052309611232, -39.7755277571212, -2.13053883162479, -37.591781844244,
+               34.1633684717672, 29.0069972464264, 24.1316007358375, -25.9864222887071,
+               -49.8242275699278, -48.9598672554151, -6.15892154315306, 1.16337971379826,
+               -47.6223466826543, 38.6937425706247, 34.0439646466938, 17.3981885305444,
+               28.3409608399292, 15.6170752733262, -3.53143594952176, -25.3309561688557,
+               -15.5283151206724, -37.9411587563038, 20.7166031267508, 11.2837696021034,
+               -34.0286000372693, 7.46434995962331, 20.9157207240955, 32.0145672661506,
+               12.2843224379444, 35.9057920317743, 22.9722398004589, -26.5263089349701,
+               19.4029956656467, -44.1004690935732, 17.5475666457743, 37.5821163849668,
+               -14.358284978876, -31.946161198529, -14.6964305387228, -16.5479970400639,
+               -48.722373418505, -29.0573994002683, 13.3363571862685, 45.5692245103506)
+
+    pos_y <- c(-46.5761429420037, 38.2439863553609, 20.0261965063628, -21.4606618074102,
+               -9.51059989449662, 14.4401700414302, 44.9147442190373, 11.2682450186758,
+               24.0685938108325, -24.870962431481, -8.01146882859514, -9.96302774286448,
+               3.29769285370759, -35.5205034224527, 7.96879139066004, -7.55249637477033,
+               16.9858126076091, 37.5808111768344, 2.23821912140651, 28.3798053445325,
+               -28.3136130644296, 16.4478023949398, -5.98824704902006, 9.24586778625189,
+               -1.09542384738207, 36.9944727921547, 46.1910898146572, 40.7505950274036,
+               49.7607619375239, -30.4505336358037, -28.4034895267469, -8.72345277836496,
+               27.7076565721677, 41.9951376238924, 8.85561141012658, -3.04245837269701,
+               -45.1137050244705, -40.5414982009767, -24.6727879893299, -45.2919860455611,
+               -42.5112055155485, -13.1917543276661, -40.850073457265, -41.8302677196561,
+               -27.7712219343686, -16.4281590103097, -27.1531853802137, 16.9457103838765,
+               -6.29062196558142, -3.4357193317133, -24.2484089091365, -38.5749361086974,
+               -13.1314930799806, -10.9645824097158, 32.4045508393872, 26.8735110113556,
+               -6.28434405084627, 38.0979862917681, -27.1293303090933, 7.81747455074677,
+               5.20099196556176, -11.5937542112238, 27.3199537994373, -47.2988889910877,
+               -0.19224290434223, -12.4145475414155, 6.23372665793533, 29.0736458708029,
+               -38.4879231566294, 8.61233866657297, -31.8099809709908, 2.41597419902637,
+               40.8106545598371, -2.1559204259618, 49.6630367101775, 20.4182148709363,
+               -48.8304953691509, 4.61626877232501, -12.8116808925648, 42.6054316290405,
+               14.9962140339475, 46.7919320532188, 33.5183430261066, 35.5936219189923,
+               21.5804760101296, 19.4874951556404, -45.8661534840926, -17.6352639537173,
+               -47.2695257201565, -31.0717200543392, -19.8878369452885, -20.9349856677383,
+               -36.2764092980074, 17.8241404162551, -42.5037175043944, 5.31469358813471,
+               27.5892762266628, -36.0062106861055, -32.2175737208069, -23.7712900249536)
+  }
 
   expect_equal(mySim$npixelsburned, burnedLast)
   expect_equivalent(mySim$caribou$x, pos_x)
@@ -886,3 +943,16 @@ test_that("simInitAndSpades", {
   expect_true(all.equal(mySim, mySim2))
 
 })
+
+test_that("scheduleEvent with invalid values for eventTime", {
+  testInitOut <- testInit()
+  on.exit({
+    testOnExit(testInitOut)
+  }, add = TRUE)
+  s <- simInit(times = list(start = 1, end = 10))
+  expect_error(s <- scheduleEvent(s, eventTime = -1, eventType = "test1", moduleName = "test"))
+  expect_warning(s <- scheduleEvent(s, eventTime = numeric(), eventType = "test1", moduleName = "test"))
+  expect_error(s <- scheduleEvent(s, eventTime = 0, eventType = "test1", moduleName = "test"))
+
+
+})
